// Debian build: bundle the type declarations with rollup-plugin-dts
// (upstream uses dts-bundle-generator, which is not packaged in Debian).
import dts from 'rollup-plugin-dts';

export default {
  input: 'source/index.ts',
  external: [/^node:/, 'ip-address', 'express', /^express\//],
  output: { file: 'dist/index.d.ts', format: 'es' },
  plugins: [dts({ tsconfig: './debian/tsconfig.json' })],
};
